Struct DieId
#[repr(transparent)]pub struct DieId(pub u32);Expand description
DIE_ID register.
Tuple Fields
0: u32Implementations
impl DieId
impl DieId
pub fn set_revision(&mut self, val: u8)
pub fn set_revision(&mut self, val: u8)
Cut revision (metal fix).
pub fn set_version(&mut self, val: u8)
pub fn set_version(&mut self, val: u8)
Cut version.
pub const fn product(&self) -> u8
pub const fn product(&self) -> u8
Product version. May be used to discriminate several version of a same digital BLE LPH device embedding different analog versions.
pub fn set_product(&mut self, val: u8)
pub fn set_product(&mut self, val: u8)
Product version. May be used to discriminate several version of a same digital BLE LPH device embedding different analog versions.